dataMovies API documentation

# Package `dataMovies`

Expand source code

    #!/usr/bin/env python3
    from .dataMoviesFeatures import search_movie_reviews_df
    from .dataMoviesFeatures import search_movies_reviews_df
    from .dataMoviesFeatures import search_movie_users_ratings_df
    from .dataMoviesFeatures import search_movies_users_ratings_df

## Sub-modules

`dataMovies.dataMoviesFeatures`
`dataMovies.errors`
`dataMovies.serializers`
`dataMovies.services`